//
//  DTCString.h
//  iArchiver
//
//  Created by Philipp on 28/12/2007.
//  Copyright 2007 Dare to be Creative Ltd. All rights reserved.
//

#import <Cocoa/Cocoa.h>


@interface NSString (DTCString)

/*
 * Adds a path extension if it doesn't yet exist
 */
-(NSString *)addExtension:(NSString *)extension;

/*
 * Returns a Boolean value that indicates whether the receiver begins with the given string
 */
- (BOOL) beginsWith:(NSString *)substring;

/*
 * Returns a Boolean value that indicates whether the receiver contains the given substring
 */
- (BOOL) hasSubstring:(NSString *)substring;

/*
 * Returns a Boolean value that indicates whether the file at the given path is a Mac hidden file
 */
- (BOOL) isMacHiddenFile;

/*
 * Replaces the path's extension
 */
- (NSString *)swapExtension: (NSString *)newExtension;

/*
 * Returns the path's extension (improves NSString's built-in pathExtension method to detect
 * some special cases)
 */
- (NSString *)pathExtensionX;


#pragma mark Misc methods

/*
 * Escape special HTML characters
 *
 * Returns an autoreleased NSString composed of the characters in the receiver modified (escaped)
 * as necessary to conform with RFC 2396 for use in URLs
 */ 
- (NSString *)stringByAddingPercentEscapes;

/*
 * De-escape special HTML characters
 *
 * Returns an autoreleased NSString composed of the characters in the receiver represented directly as
 * Unicode characters rather than RFC 2396 escaped characters.
 */
- (NSString *)stringByReplacingPercentEscapes;

/*
 * Returns a Cocoa NSString for the specified CFString.
 *
 * Liberally taken from
 *   http://developer.apple.com/samplecode/ColorMatching/listing22.html
 */
+(NSString *)cocoaStringFromCFStringRef:(CFStringRef)cfStr;

@end
