//
//  DTCTaskWrapper.h
//  iArchiver
//
//  Created by Philipp on 29/12/2007.
//  Copyright 2007 Dare to be Creative Ltd. All rights reserved.
//
//
// Generic task wrapper that provides delegates with an NSTask's output line by line
//

#import <Cocoa/Cocoa.h>


@protocol DTCTaskDelegate <NSObject>

/*
 * Sent when the wrapped task emits a line of output
 *
 * Note: the task wrapper doesn't retain a copy of the output (it's autoreleased), so the receiver
 *       must retain it explicitly
 */
 -(void) task:(NSTask *)task hasOutputAvailable:(NSString *)outputLine;

/*
 * Sent when the wrapped task completes
 */
-(void) task:(NSTask *)task hasCompletedWithStatus:(int) status;

@end


@interface DTCTaskWrapper : NSObject {
	NSTask *task;
	id <DTCTaskDelegate> delegate;
	NSPipe *inputPipe;
}


#pragma mark Instance methods

/*
 * Returns a DTCTaskWrapper object with the given delegate registered for the given task
 */
-(id) initWithDelegate:(id <DTCTaskDelegate>)aDelegate forTask:(NSTask *)aTask;

/*
 * Run the task and forward the output it emits to the delegate
 */
-(void) launchTask;

/*
 * Send data to the running task
 */
- (void)sendData:(NSString *)dataString;

/*
 * Private observer method that intercepts task data, breaks it into lines and forwards
 * each line to the delegate
 */
-(void) taskDataAvailable:(NSNotification *)aNotification;


#pragma mark Deprecated methods

/*!
 * @deprecated in version 1.3 - use the equivalent method in NSTask+Quickies.h
 */
// TODO: find a compiler flag that this method shows up as deprecated when compiling
//       (the @deprecated directive in the comment above seems to be only for comments
+ (NSString *) runCommand:(NSString *)aCommand withArguments:(NSArray *)anArgumentList;

@end
