//
//  RegistrationController.h
//  DTCRegistration
//
//  Created by Philipp on 20/10/2007.
//  Copyright 2007 Dare to be Creative Ltd. All rights reserved.
//

#import <Cocoa/Cocoa.h>


@interface RegistrationController : NSWindowController {
	IBOutlet NSTextField *licenseKeyTextField;
	IBOutlet NSButton *registerButton;
	
	NSDate *expiryDate;

	NSString *productName;
	NSString *ESDSerialNumber;
	NSString *publisherKey;
	NSString *esellerID, *skuID, *previewID, *affiliateID, *layoutCertificate;
	NSString *receiptPage;
	float price;
}

/*
 * Initialize the controller with the given
 *   - product name
 *   - SKU ID
 *   - eseller (store) ID
 *   - preview ID (can be set to NULL in production mode)
 *   - affiliate ID: the web store ID
 *   - layoutCertificate: to test unpublished custom layouts (optional)
 *   - publisher key (found in the web interface, serial number set details page)
 *   - receipt page link
 *   - hidden file name for the trial period
 *   - number of days until expiry
 */
- (id) initWithProduct:(NSString *) aProductName
				 SkuID:(NSString *) aSkuID
			 esellerID:(NSString *) aEsellerID
			 previewID:(NSString *) aPreviewID
		   affiliateID:(NSString *) anAffiliateID
	 layoutCertificate:(NSString *) aLayoutCertificate
		  publisherKey:(NSString *) aPublisherKey
				 price:(float) aPrice
		   receiptPage:(NSString *) aLink
		   securedWith:(NSString *) aFile
	   forExpiryInDays:(int) days;

/*
 * Launches the registration/trial period code
 */
- (void) launch;

/*
 * Saves a license key and email to the user defaults database
 */
- (void)registerKey:(NSString *)licenseKey forEmail:(NSString *)email;


- (IBAction)saveRegistration:(id)sender;
- (IBAction)cancelRegistration:(id)sender;

- (BOOL)registerApp;
- (BOOL)buyApp;

/*
 * Number of days left in the trial period
 */
- (int) trialDaysLeft;

/*
 * Has the license expired?
 */
- (BOOL) licenseHasExpired;

/*
 * Is the current email-key combination valid?
 */
- (BOOL)hasValidKey;


/*
 *****************
 * Private methods
 *****************
 */

/*
 * Shows the trial period options
 */
- (void) showTrialPeriodOptions;

/*
 * Shows the trial-period-expired options
 */
- (void) showExpiredOptions;

// Install the EWS engine
- (OSStatus)installEngine;

-(void) panelUpdated;

@end
